@@ -7,18 +7,15 @@ from sklearn.cluster import KMeans
 
 from osprey.config import Config
 from osprey.search_space import IntVariable, FloatVariable, EnumVariable
-from osprey import search_engines
+from osprey.strategies import RandomSearch, HyperoptTPE, MOE
 
 
 os.environ['OSPREYRC'] = ' '
 
 
-def mock_eval_globals():
-    return {'KMeans': KMeans}
-
-
 def test_estimator_pickle():
     with tempfile.NamedTemporaryFile('w+b', 0) as f:
+
         cPickle.dump(KMeans(), f)
 
         config = Config.fromdict({
@@ -27,11 +24,21 @@ def test_estimator_pickle():
         assert isinstance(config.estimator(), KMeans)
 
 
-def test_estimator_eval():
+def test_estimator_eval_1():
     config = Config.fromdict({
         'estimator': {
             'eval': 'KMeans()',
-            '__eval_globals__': 'osprey.tests.test_config.mock_eval_globals'
+            'eval_scope': 'sklearn',
+        }
+    }, check_fields=False)
+    assert isinstance(config.estimator(), KMeans)
+
+
+def test_estimator_eval_2():
+    config = Config.fromdict({
+        'estimator': {
+            'eval': 'KMeans()',
+            'eval_scope': ['sklearn'],
         }
     }, check_fields=False)
     assert isinstance(config.estimator(), KMeans)
@@ -48,12 +55,12 @@ def test_estimator_entry_point():
 
 def test_search_space():
     config = Config.fromdict({
-        'search': {'space': {
+        'search_space': {
             'intvar': {'type': 'int', 'min': 1, 'max': 2},
             'fvar': {'type': 'float', 'min': 1, 'max': 3.5},
             'logvar': {'type': 'float', 'min': 1, 'max': 2.5, 'warp': 'log'},
             'enumvar': {'type': 'enum', 'choices': [1, False]},
-        }}}, check_fields=False)
+        }}, check_fields=False)
     searchspace = config.search_space()
     assert searchspace['intvar'] == IntVariable('intvar', 1, 2)
     assert searchspace['fvar'] == FloatVariable('fvar', 1, 3.5, warp=None)
@@ -61,18 +68,34 @@ def test_search_space():
     assert searchspace['enumvar'] == EnumVariable('enumvar', [1, False])
 
 
-def test_search_engine_random():
+def test_strategy_random():
     config = Config.fromdict({
-        'search': {'engine': 'random'}
+        'strategy': {'name': 'random'}
     }, check_fields=False)
-    assert config.search_engine() is search_engines.random
+    assert isinstance(config.strategy(), RandomSearch)
 
 
 def test_search_engine_hyperopt_tpe():
     config = Config.fromdict({
-        'search': {'engine': 'hyperopt_tpe'}
+        'strategy': {'name': 'hyperopt_tpe'}
     }, check_fields=False)
-    assert config.search_engine() is search_engines.hyperopt_tpe
+    assert isinstance(config.strategy(), HyperoptTPE)
+
+
+def test_search_engine_moe_1():
+    config = Config.fromdict({
+        'strategy': {'name': 'moe', 'params': {'url': 'sdfsdf'}}
+    }, check_fields=False)
+    assert isinstance(config.strategy(), MOE)
+
+
+def test_search_engine_moe_2():
+    config = Config.fromdict({
+        'strategy': {'name': 'moe', 'params': {'url': 'abc'}}
+    }, check_fields=False)
+    strat = config.strategy()
+    assert isinstance(strat, MOE)
+    assert strat.url == 'abc'
 
 
 def test_scoring():
